==> plugin_codelab_new-0.0.1.tar.gz: lib/service/http_service.dart <==
import 'dart:core';
import 'dart:convert';
import 'dart:developer';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:http/http.dart';
import 'package:localstorage/localstorage.dart';
import 'package:plugin_codelab_new/exeptions/auth_exception.dart';
import 'package:plugin_codelab_new/utilities/jwt.dart';
import '../environment_config.dart';

final storage = new LocalStorage('my_data');

class HttpService {
  final String apiURL = 'https://${EnvironmentConfig.API_URL}';
  String _jwt;

  HttpService(this._jwt);

  String getUserId() {
    if (_jwt == null) {
      return null;
    }
    final currentUser = parseJWT(_jwt);
    return currentUser != null ? currentUser['id'] : null;
  }

  Future<Response> get(url, {Map<String, String> headers}) async {
    final response = await http.get(url, headers: headers);
    if (response.statusCode == 401) {
      if (json.decode(response.body)['message'] == 'Expired JWT Token') {
        throw ExpiredTokenException(response.reasonPhrase);
      } else {
        throw AuthenticateException(response.reasonPhrase);
      }
    } else {
      return response;
    }
  }

  Future<Response> post(url,
      {Map<String, String> headers, body, Encoding encoding}) async {
    final response =
        await http.post(url, headers: headers, body: body, encoding: encoding);
    if (response.statusCode == 401 &&
        json.decode(response.body)['message'] == 'Expired JWT Token') {
      throw ExpiredTokenException(response.reasonPhrase);
    } else {
      return response;
    }
  }

  Future<Response> put(url,
      {Map<String, String> headers, body, Encoding encoding}) async {
    final response =
        await http.put(url, headers: headers, body: body, encoding: encoding);
    if (response.statusCode == 401 &&
        json.decode(response.body)['message'] == 'Expired JWT Token') {
      throw ExpiredTokenException(response.reasonPhrase);
    } else {
      return response;
    }
  }

  Future<http.Response> fetchUser(id) {
    final userId = id;
    return get('$apiURL/users/getById?id=$userId', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> fetchAllPosts() {
    return get('$apiURL/posts/all', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  //get post by user id
  Future<http.Response> fetchPostsByUserId(id) async {
    return get('$apiURL/posts/byUserId?user=$id', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> fetchCommentsByPostId(postId) async {
    return get('$apiURL/post-comments/byPostId?post=$postId', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> addPost(
      {@required int userId,
      @required String description,
      @required String type,
      String attachedUrl}) {
    var data = json.encode({
      "user": userId,
      "description": description,
      "type": type,
      "attachedUrl": attachedUrl,
      "title": "wowowowo"
    });
    log(data);

    return post('$apiURL/posts/create',
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> uploadComment({
    @required int userId,
    @required int postId,
    @required String comment,
  }) {
    var data = json.encode({
      "user": userId,
      "post": postId,
      "comment": comment,
    });
    log(data);

    return post('$apiURL/post-comments/create',
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  //Reports:
  Future<http.Response> fetchAllReports() {
    return get('$apiURL/report-types/all', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

//sub Reports:
  Future<http.Response> fetchSubReport(reportTypeId) async {
    return get(
        '$apiURL/report-sub-types/byReportTypeId?reportType=$reportTypeId',
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
        });
  }

  // /reports/get-by-type
  Future<http.Response> fetchReportByPostId(id) async {
    return await get('$apiURL/reports/byPostId?post=$id', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  //login by phone number
  // Future login({@required String phoneNumber}) async {
  //   var data = json.encode({"phoneNumber": phoneNumber});
  //   log(data);
  //   Map<String, dynamic> res;
  //   int phoneDoResult;
  //   Response result = await post('$apiURL/feed-api/login',
  //       headers: {
  //         "token":
  //             "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
  //         "content-type": 'application/json',
  //       },
  //       body: data);
  //   res = json.decode(result.body);
  //   phoneDoResult = res["data"][0]["id"];
  //   // storage.setItem("userId", phoneDoResult);
  // }

  Future<http.Response> addReport(
      {@required int typeId, @required int userId, @required int postId}) {
    var data = json.encode({"type": typeId, "user": userId, "post": postId});
    log(data);
    return post('$apiURL/reports/create',
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  //remove report
  Future<http.Response> removeReport({@required reportId}) {
    return delete('$apiURL/reports/remove?id=$reportId', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> fetchAllSubType() {
    return get('$apiURL/report-sub-types/all', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }
}

==> plugin_codelab_new-0.0.2.tar.gz: lib/service/http_service.dart <==
import 'dart:core';
import 'dart:convert';
import 'dart:developer';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:http/http.dart';
import 'package:plugin_codelab_new/exeptions/auth_exception.dart';
import '../environment_config.dart';

class HttpService {
  final String apiURL = 'https://${EnvironmentConfig.API_URL}';
  String _jwt;

  HttpService(this._jwt);

  Future<Response> get(url, {Map<String, String> headers}) async {
    final response = await http.get(url, headers: headers);
    if (response.statusCode == 401) {
      if (json.decode(response.body)['message'] == 'Expired JWT Token') {
        throw ExpiredTokenException(response.reasonPhrase);
      } else {
        throw AuthenticateException(response.reasonPhrase);
      }
    } else {
      return response;
    }
  }

  Future<Response> post(url,
      {Map<String, String> headers, body, Encoding encoding}) async {
    final response =
        await http.post(url, headers: headers, body: body, encoding: encoding);
    if (response.statusCode == 401 &&
        json.decode(response.body)['message'] == 'Expired JWT Token') {
      throw ExpiredTokenException(response.reasonPhrase);
    } else {
      return response;
    }
  }

  Future<Response> put(url,
      {Map<String, String> headers, body, Encoding encoding}) async {
    final response =
        await http.put(url, headers: headers, body: body, encoding: encoding);
    if (response.statusCode == 401 &&
        json.decode(response.body)['message'] == 'Expired JWT Token') {
      throw ExpiredTokenException(response.reasonPhrase);
    } else {
      return response;
    }
  }

  Future<http.Response> fetchUser(id) {
    final userId = id;
    return get('$apiURL/users/getById?id=$userId', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> fetchAllPosts() {
    return get('$apiURL/posts/all', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> fetchPostsByUserId(id) async {
    return get('$apiURL/posts/byUserId?user=$id', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> fetchFavoritePosts(currentUserId, saveId) async {
    return get('$apiURL/reports/favorite?user=$currentUserId&saveId=$saveId',
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
        });
  }

  Future<http.Response> fetchCommentsByPostId(postId) async {
    return get('$apiURL/post-comments/byPostId?post=$postId', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> addPost(
      {@required int userId,
      @required String description,
      @required String type,
      String attachedUrl}) {
    var data = json.encode({
      "user": userId,
      "description": description,
      "type": type,
      "attachedUrl": attachedUrl,
      "title": "wowowowo"
    });
    log(data);

    return post('$apiURL/posts/create',
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> uploadComment({
    @required int userId,
    @required int postId,
    @required String comment,
  }) {
    var data = json.encode({
      "user": userId,
      "post": postId,
      "comment": comment,
    });
    log(data);

    return post('$apiURL/post-comments/create',
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> fetchAllReports() {
    return get('$apiURL/report-types/all', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> fetchSubReport(reportTypeId) async {
    return get(
        '$apiURL/report-sub-types/byReportTypeId?reportType=$reportTypeId',
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
        });
  }

  Future<http.Response> fetchReportByPostId(id) async {
    return await get('$apiURL/reports/byPostId?post=$id', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> addReport(
      {@required int typeId, @required int userId, @required int postId}) {
    var data = json.encode({"type": typeId, "user": userId, "post": postId});
    log(data);
    return post('$apiURL/reports/create',
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
          "content-type": 'application/json',
        },
        body: data);
  }

  Future<http.Response> updatePostReport({@required int postId}) {
    return put('$apiURL/posts/reports?post=$postId', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve",
      "content-type": 'application/json',
    });
  }

  Future<http.Response> removeReport({@required reportId}) {
    return delete(Uri.parse('$apiURL/reports/remove?id=$reportId'), headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> fetchAllSubType() {
    return get('$apiURL/report-sub-types/all', headers: {
      "token":
          "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
    });
  }

  Future<http.Response> authenticateUser(
      {@required firstName,
      @required lastName,
      @required about,
      @required profileImg,
      @required token}) {
    return get(
        '$apiURL/users/authenticate?firstName=$firstName&lastName=$lastName&about=$about&profileImg=$profileImg&token=$token',
        headers: {
          "token":
              "cnejwi8c9wehnd8fchni2x239jxexnjx2n23i8xn3oifr0cwd32fjnrf453vreve"
        });
  }
}
